@@ -78,8 +78,9 @@ function parseArrival(res, line, year) {
 function parseLegs(text, year, compact) {
     var reservations = new Array();
     var lines = text.split('\n');
+    var offset = lines[0].match(/^ */);
     for (var i = 0; compact && i < lines.length; ++i)
-        lines[i] = lines[i].substr(6);
+        lines[i] = lines[i].substr(offset[0].length);
 
     var depIdx = 0, arrIdx = 1;
     while (depIdx < lines.length) {
